searchData={"items":[{"type":"module","title":"ExWebRTC.Recorder","doc":"Saves received RTP packets to a file for later processing/analysis.\n\nDumps raw RTP packets fed to it in a custom format. Use `ExWebRTC.Recorder.Converter` to process them.\n\nCan optionally upload the saved files to S3-compatible storage.\nSee `ExWebRTC.Recorder.S3` and `t:options/0` for more info.","ref":"ExWebRTC.Recorder.html"},{"type":"function","title":"ExWebRTC.Recorder.add_tracks/2","doc":"Adds new tracks to the recording.\n\nReturns the part of the recording manifest that's relevant to the freshly added tracks.\nSee `t:ExWebRTC.Recorder.Manifest.t/0` for more info.","ref":"ExWebRTC.Recorder.html#add_tracks/2"},{"type":"function","title":"ExWebRTC.Recorder.controlling_process/2","doc":"Changes the controlling process of this `recorder` process.\n\nControlling process is a process that receives all of the messages (described\nby `t:message/0`) from this Recorder.","ref":"ExWebRTC.Recorder.html#controlling_process/2"},{"type":"function","title":"ExWebRTC.Recorder.end_tracks/2","doc":"Finishes the recording for the given tracks and optionally uploads the result files.\n\nSee `t:end_tracks_ok_result/0` for the success typing.","ref":"ExWebRTC.Recorder.html#end_tracks/2"},{"type":"type","title":"ExWebRTC.Recorder.end_tracks_ok_result/0","doc":"Tuple returned on successful call to `end_tracks/2`.\n\nContains the part of the recording manifest that's relevant to the freshly ended tracks.\nSee `t:ExWebRTC.Recorder.Manifest.t/0` for more info.\n\nIf uploads are configured:\n* Contains the reference to the upload task that was spawned.\n* Recorder will send the `:upload_complete`/`:upload_failed` message with this reference\n  to its controlling process when the task finishes.\n\nNote that the manifest returned by `end_tracks/2` always contains local paths to files.\nThe updated manifest with `s3://` scheme URLs is sent in the aforementioned message.","ref":"ExWebRTC.Recorder.html#t:end_tracks_ok_result/0"},{"type":"type","title":"ExWebRTC.Recorder.message/0","doc":"Messages sent by the `ExWebRTC.Recorder` process to its controlling process.\n\n* `:upload_complete`, `:upload_failed` - Sent after the completion of the upload task, identified by its reference.\n  Contains the updated manifest with `s3://` scheme URLs to uploaded files.","ref":"ExWebRTC.Recorder.html#t:message/0"},{"type":"type","title":"ExWebRTC.Recorder.option/0","doc":"Options that can be passed to `start_link/1`.\n\n* `:base_dir` - Base directory where Recorder will save its artifacts. `./recordings` by default.\n* `:on_start` - Callback that will be executed just after the Recorder is (re)started.\n   It should return the initial list of tracks to be added.\n* `:controlling_process` - PID of a process where all messages will be sent. `self()` by default.\n* `:s3_upload_config` - If passed, finished recordings will be uploaded to S3-compatible storage.\n   See `t:ExWebRTC.Recorder.S3.upload_config/0` for more info.","ref":"ExWebRTC.Recorder.html#t:option/0"},{"type":"type","title":"ExWebRTC.Recorder.options/0","doc":"","ref":"ExWebRTC.Recorder.html#t:options/0"},{"type":"function","title":"ExWebRTC.Recorder.record/4","doc":"Records a received packet on the given track.","ref":"ExWebRTC.Recorder.html#record/4"},{"type":"type","title":"ExWebRTC.Recorder.recorder/0","doc":"","ref":"ExWebRTC.Recorder.html#t:recorder/0"},{"type":"function","title":"ExWebRTC.Recorder.start/2","doc":"Starts a new `ExWebRTC.Recorder` process.\n\n`ExWebRTC.Recorder` is a `GenServer` under the hood, thus this function allows for\npassing the generic `t:GenServer.options/0` as an argument.","ref":"ExWebRTC.Recorder.html#start/2"},{"type":"function","title":"ExWebRTC.Recorder.start_link/2","doc":"Starts a new `ExWebRTC.Recorder` process.\n\nWorks identically to `start/2`, but links to the calling process.","ref":"ExWebRTC.Recorder.html#start_link/2"},{"type":"module","title":"ExWebRTC.Recorder.Converter","doc":"Processes RTP packet files saved by `ExWebRTC.Recorder`.\n\nRequires the `ffmpeg` binary with the relevant libraries present in `PATH`.\n\nAt the moment, `ExWebRTC.Recorder.Converter` works only with VP8 video and Opus audio.\n\nCan optionally download/upload the source/result files from/to S3-compatible storage.\nSee `ExWebRTC.Recorder.S3` and `t:options/0` for more info.","ref":"ExWebRTC.Recorder.Converter.html"},{"type":"function","title":"ExWebRTC.Recorder.Converter.convert!/2","doc":"Converts the saved dumps of tracks in the manifest to WEBM files.\n\nIf passed a path as the first argument, loads the recording manifest from file.","ref":"ExWebRTC.Recorder.Converter.html#convert!/2"},{"type":"type","title":"ExWebRTC.Recorder.Converter.option/0","doc":"Options that can be passed to `convert!/2`.\n\n* `:output_path` - Directory where Converter will save its artifacts. `./converter/output` by default.\n* `:s3_upload_config` - If passed, processed recordings will be uploaded to S3-compatible storage.\n  See `t:ExWebRTC.Recorder.S3.upload_config/0` for more info.\n* `:download_path` - Directory where Converter will save files fetched from S3. `./converter/download` by default.\n* `:s3_download_config` - Optional S3 config overrides used when fetching files.\n  See `t:ExWebRTC.Recorder.S3.override_config/0` for more info.\n* `:thumbnails_ctx` - If passed, Converter will generate thumbnails for the output files.\n  See `t:thumbnails_ctx/0` for more info.\n* `:only_rids` - By default, when processing a video track with multiple layers (i.e. simulcast),\n  Converter generates multiple output files, one per layer. If passed, Converter will only process\n  the layers with RIDs present in this list. E.g. if you want to receive a single video file\n  from the layer `\"h\"`, pass `[\"h\"]`. For single-layer tracks RID is set to `nil`,\n  so if you want to handle both simulcast and regular tracks, pass `[\"h\", nil]`.","ref":"ExWebRTC.Recorder.Converter.html#t:option/0"},{"type":"type","title":"ExWebRTC.Recorder.Converter.options/0","doc":"","ref":"ExWebRTC.Recorder.Converter.html#t:options/0"},{"type":"type","title":"ExWebRTC.Recorder.Converter.thumbnails_ctx/0","doc":"Context for the thumbnail generation.\n\n* `:width` - Thumbnail width. 640 by default.\n* `:height` - Thumbnail height. -1 by default.\n\nSetting either of the values to `-1` will fit the size to the aspect ratio.","ref":"ExWebRTC.Recorder.Converter.html#t:thumbnails_ctx/0"},{"type":"module","title":"ExWebRTC.Recorder.Converter.Manifest","doc":"Lists the streams processed using the Converter.\n\nConverter combines the tracks from the Recording based on their `:streams` field.","ref":"ExWebRTC.Recorder.Converter.Manifest.html"},{"type":"type","title":"ExWebRTC.Recorder.Converter.Manifest.file_manifest/0","doc":"","ref":"ExWebRTC.Recorder.Converter.Manifest.html#t:file_manifest/0"},{"type":"type","title":"ExWebRTC.Recorder.Converter.Manifest.t/0","doc":"","ref":"ExWebRTC.Recorder.Converter.Manifest.html#t:t/0"},{"type":"module","title":"ExWebRTC.Recorder.Manifest","doc":"Lists the tracks recorded by a specific Recorder instance.","ref":"ExWebRTC.Recorder.Manifest.html"},{"type":"type","title":"ExWebRTC.Recorder.Manifest.location/0","doc":"Location of a manifest entry.\n\nCan be one of the following:\n* Local path, e.g. `\"foo/bar/recording.webm\"`\n* URL with the `file://` scheme, e.g. `\"file:///baz/qux/recording.webm\"`\n* URL with the `s3://` scheme, e.g. `\"s3://my-bucket-name/abc/recording.webm\"`","ref":"ExWebRTC.Recorder.Manifest.html#t:location/0"},{"type":"type","title":"ExWebRTC.Recorder.Manifest.t/0","doc":"","ref":"ExWebRTC.Recorder.Manifest.html#t:t/0"},{"type":"type","title":"ExWebRTC.Recorder.Manifest.track_manifest/0","doc":"","ref":"ExWebRTC.Recorder.Manifest.html#t:track_manifest/0"},{"type":"module","title":"ExWebRTC.Recorder.S3","doc":"`ExWebRTC.Recorder` and `ExWebRTC.Recorder.Converter` can optionally upload/download files to/from S3-compatible storage.\n\nTo use this functionality, you must add the following dependencies to your project:\n* `:ex_aws_s3`\n* `:ex_aws`\n* `:sweet_xml`\n* an HTTP client (e.g. `:req`)","ref":"ExWebRTC.Recorder.S3.html"},{"type":"type","title":"ExWebRTC.Recorder.S3.override_config/0","doc":"","ref":"ExWebRTC.Recorder.S3.html#t:override_config/0"},{"type":"type","title":"ExWebRTC.Recorder.S3.override_option/0","doc":"Options described [here](https://hexdocs.pm/ex_aws_s3/ExAws.S3.html#module-configuration)\nand [here](https://hexdocs.pm/ex_aws/readme.html#aws-key-configuration)\n(e.g. `:access_key_id`, `:secret_access_key` `:scheme`, `:host`, `:port`, `:region`).\n\nThey can be passed in order to override values defined in the application config (or environment variables).","ref":"ExWebRTC.Recorder.S3.html#t:override_option/0"},{"type":"type","title":"ExWebRTC.Recorder.S3.upload_config/0","doc":"","ref":"ExWebRTC.Recorder.S3.html#t:upload_config/0"},{"type":"type","title":"ExWebRTC.Recorder.S3.upload_option/0","doc":"Options for configuring upload of artifacts to S3-compatible storage.\n\n* `:bucket_name` (required) - Name of bucket objects will be uploaded to.\n* `:base_path` - S3 path prefix used for objects uploaded to the bucket. `\"\"` by default.","ref":"ExWebRTC.Recorder.S3.html#t:upload_option/0"},{"type":"opaque","title":"ExWebRTC.Recorder.S3.upload_task_ref/0","doc":"Reference to a started batch upload task.","ref":"ExWebRTC.Recorder.S3.html#t:upload_task_ref/0"},{"type":"extras","title":"ExWebRTC Recorder","doc":"# ExWebRTC Recorder\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_webrtc_recorder.svg)](https://hex.pm/packages/ex_webrtc_recorder)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_webrtc_recorder)\n\nRecords and processes RTP packets sent and received using [ExWebRTC](https://github.com/elixir-webrtc/ex_webrtc).","ref":"readme.html"},{"type":"extras","title":"Installation - ExWebRTC Recorder","doc":"Add `:ex_webrtc_recorder` to your list of dependencies\n\n```elixir\ndef deps do\n  [\n    {:ex_webrtc_recorder, \"~> 0.2.1\"}\n  ]\nend\n```\n\nIf you want to use Converter to generate WEBM files from the recordings,\nyou need to have the `ffmpeg` binary with the relevant libraries present in `PATH`.","ref":"readme.html#installation"},{"type":"extras","title":"S3 - ExWebRTC Recorder","doc":"ExWebRTC Recorder comes with optional support for uploading the recordings to S3-compatible storage,\nbut it must be explicitly turned on by adding the following dependencies:\n\n```elixir\ndef deps do\n  [\n    {:ex_webrtc_recorder, \"~> 0.2.1\"},\n    {:ex_aws_s3, \"~> 2.5\"},\n    {:ex_aws, \"~> 2.5\"},\n    {:sweet_xml, \"~> 0.7\"},\n    {:req, \"~> 0.5\"}         # or any other HTTP client supported by `ex_aws`\n  ]\nend\n```\n\nSee `ExWebRTC.Recorder.S3` for more info.","ref":"readme.html#s3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}